@@ -265,8 +265,8 @@ l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
   ---------------------------------------------------------------------------
   escape        class
   ---------------------------------------------------------------------------
-  \b            (?:(?:\A|(?<=[\x81-\x9F\xE0-\xFC][\x00-\xFF])|(?<=[^0-9A-Z_a-z]))(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z]|\z))
-  \B            (?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?:(?<=[\x81-\x9F\xE0-\xFC][\x00-\xFF])|(?<=[^0-9A-Z_a-z]))(?=[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z]))
+  \b            (?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))
+  \B            (?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))
   ---------------------------------------------------------------------------
 
 =head1 g݊֐̃GXP[v
